summaryrefslogtreecommitdiff
path: root/cmd/srv9p/gnet.h
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/srv9p/gnet.h')
-rw-r--r--cmd/srv9p/gnet.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmd/srv9p/gnet.h b/cmd/srv9p/gnet.h
index d43874f..01f2d40 100644
--- a/cmd/srv9p/gnet.h
+++ b/cmd/srv9p/gnet.h
@@ -1,4 +1,4 @@
/* srv9p/gnet.h - libnet implementation for libcr + GNU libc
*
* Copyright (C) 2024 Luke T. Shumaker <lukeshu@lukeshu.com>
* SPDX-Licence-Identifier: AGPL-3.0-or-later
@@ -9,16 +9,16 @@
#include <stdint.h> /* for uint16_6 */
-#include <libnet/libnet.h>
+#include <libmisc/net.h>
struct _gnet_conn {
- struct libnet_conn_vtable *vtable;
+ implements_net_conn;
int fd;
};
struct gnet_listener {
- struct libnet_listener_vtable *vtable;
+ implements_net_listener;
int fd;
struct _gnet_conn active_conn;
@@ -1,4 +1,4 @@
-/* srv9p/gnet.h - libnet implementation for libcr + GNU libc
+/* srv9p/gnet.h - libmisc/net.h implementation for libcr + GNU libc
*
* Copyright (C) 2024 Luke T. Shumaker <lukeshu@lukeshu.com>